svn commit: r16267 - trunk/src/argouml-app/src/org/argouml/uml/diagram/ui/PathItemPlacement.java

Dave Thompson <[email protected]>
Newsgroups gmane.comp.lang.uml.argouml.cvs
Message-ID <[email protected]>
Author: dthompson
Date: 2008-12-06 13:58:16-0800
New Revision: 16267

Modified:
   trunk/src/argouml-app/src/org/argouml/uml/diagram/ui/PathItemPlacement.java

Log:
Renamed a parameter for clarity, no functional change.

Modified: trunk/src/argouml-app/src/org/argouml/uml/diagram/ui/PathItemPlacement.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src/argouml-app/src/org/argouml/uml/diagram/ui/PathItemPlacement.java?view=diff&pathrev=16267&r1=16266&r2=16267
==============================================================================
--- trunk/src/argouml-app/src/org/argouml/uml/diagram/ui/PathItemPlacement.java	(original)
+++ trunk/src/argouml-app/src/org/argouml/uml/diagram/ui/PathItemPlacement.java	2008-12-06 13:58:16-0800
@@ -420,10 +420,10 @@
 
     /**
      * Set distance along displacement vector to place the figure.
      * @param newOffset distance in units of the drawing coordinate system
      */
-    public void setDisplacementDistance(int newOffset) {
-        vectorOffset = newOffset;
+    public void setDisplacementDistance(int newDistance) {
+        vectorOffset = newDistance;
         useAngle = true;
     }

------------------------------------------------------
@@ -420,10 +420,10 @@
     /**
      * Set distance along displacement vector to place the figure.
-     * @param newOffset distance in units of the drawing coordinate system
+     * @param newDistance distance in units of the drawing coordinate system
      */
http://argouml.tigris.org/ds/viewMessage.do?dsForumId=5905&dsMessageId=980618

To unsubscribe from this discussion, e-mail: [[email protected]].
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.